function y = CVappfun(x, Qc, Qs, D)
% -------------------------------------------------------------------------
% CVappfun.m
%
% Author         David Humphreys and Peter Harris, NPL
% Created        13-04-2014
% Last amended   13-04-2014
% Released       30-06-2014
% -------------------------------------------------------------------------
% Evaluator for "eigs" function.
%
% See: Guidance for the use of compact covariance uncertainty software,
%      David Humphreys and Peter Harris, NPL REPORT TQE 10, 2014
% -------------------------------------------------------------------------
% Input:
%    x          2n x 1        Arbitrary vector.
%    Qc,
%    Qs          n x nei
%    D           n x 3        Submatrices defining compact representation
%                             of covariance matrix.
%
% Output:
%    y          2n x 1        Matrix-vector product:
%                                y = V*x
% -------------------------------------------------------------------------

  [CC, SS, CS] = CVgen(Qc, Qs, D);
  y            = [CC, CS'; CS, SS]*x;
%
% -------------------------------------------------------------------------
% End.
%
% Copyright NPL. No warranty or guarantee applies to this software, and 
% therefore any users should satisfy themselves that it meets their 
% requirements.
% -------------------------------------------------------------------------