function y = CVfun_compact(x, pname, n)
% -------------------------------------------------------------------------
% CVfun_compact.m
%
% Author         David Humphreys and Peter Harris, NPL
% Created        24-07-2013   From CVfun_compact.m to avoid forming full 
%                             covariance matrix.
% Last amended   26-03-2014   Added input/output parameters.
% Released       30-06-2014
% -------------------------------------------------------------------------
% Evaluator for "eigs" function without storing the full covariance matrix.
%
% See: Guidance for the use of compact covariance uncertainty software,
%      David Humphreys and Peter Harris, NPL REPORT TQE 10, 2014
% -------------------------------------------------------------------------
% Input:
%    x          2n x 1        Arbitrary vector.
%    pname      string        Pathname to folder containing harmonic
%                             results.
%    n           1 x 1        Number of harmonics (excluding DC).
%
% Output:
%    y          2n x 1        Matrix-vector product:
%                                y = V*x
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Initialise product y of covariance matrix with arbitrary vector x.
%
  y = zeros(2*n,1);
%
% Form components of product y one component at a time. 
%
  for i = 1:2*n
     load([pname, 'tempcv\', int2str(i)]);
     y(i) = sparse(Vzi0)*x;
  end
%
% -------------------------------------------------------------------------
% End.
%
% Copyright NPL. No warranty or guarantee applies to this software, and 
% therefore any users should satisfy themselves that it meets their 
% requirements.
% -------------------------------------------------------------------------