function [CC, SS, CS] = CVgen(Qc, Qs, D)
% -------------------------------------------------------------------------
% CVgen.m
%
% Author         David Humphreys and Peter Harris, NPL
% Created        07-06-2012
% Last amended   07-06-2012
% Released       08-02-2013
% Last amended   26-03-2014   Added input/output parameters.
% Released       30-06-2014
% -------------------------------------------------------------------------
% Create full covariance matrix from compact representation.
%
% See: Guidance for the use of compact covariance uncertainty software,
%      David Humphreys and Peter Harris, NPL REPORT TQE 10, 2014
% -------------------------------------------------------------------------
% Input:
%    Qc,
%    Qs          n x nei
%    D           n x 3        Submatrices defining compact representation.
%
% Output:
%    CC,
%    SS,
%    CS          n x n        Submatrices defining full covariance matrix:
%                                V = [CC, CS'; CS, SS]
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Form approximation to covariance matrix based on its eigendecomposition.
%
  CC = diag(D(:,1)) + Qc*Qc'; 
  CS = diag(D(:,2)) + Qs*Qc';
  SS = diag(D(:,3)) + Qs*Qs';
%
% -------------------------------------------------------------------------
% End.
%
% Copyright NPL. No warranty or guarantee applies to this software, and 
% therefore any users should satisfy themselves that it meets their 
% requirements.
% -------------------------------------------------------------------------