function [DC, f0, Rzref, Izref, CVx] = ...
  FormCovarianceMatrixFromCompactCV_eig(RESULT)
% -------------------------------------------------------------------------
% FormCovarianceMatrixFromCompactCV_eig.m
%
% Author         David Humphreys and Peter Harris, NPL
% Created        04-02-2013
% Last amended   06-02-2013
% Released       08-02-2013
% Last amended   15-07-2013   Incorporated path name.
%                13-04-2014   Added DC and input/output parameters.
% Released       30-06-2014
% -------------------------------------------------------------------------
% Form covariance matrix from compact representation.
%
% See: Guidance for the use of compact covariance uncertainty software,
%      David Humphreys and Peter Harris, NPL REPORT TQE 10, 2014
% -------------------------------------------------------------------------
% Input:
%    RESULT                   Array storing compact representation of
%                             covariance matrix (optional).
%
% Output:
%    DC          1 x 1        DC value.
%    f0          1 x 1        Frequency spacing (in GHz).
%    Rzref       n x 1        Real part of aligned and averaged harmomic 
%                             results.
%    Izref       n x 1        Imaginary part of aligned and averaged
%                             harmonic results.
%    CVx        2n x 2n       Full covariance matrix:
%                                V = [CCx, CSx'; CSx, SSx]
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% If required, select a file containing an array RESULT, and load array.
%
  if nargin < 1
     [fname, pname] = uigetfile('*.mat', 'Select a RESULT file');
     load([pname, fname])
  end
%
% -------------------------------------------------------------------------
% Extract information about compressed covariance matrix from array RESULT.
%
  [~, DC, ~, f0, Rzref, Izref, D, Qc, Qs] = LoadCompactCV_eig(RESULT);
%
% -------------------------------------------------------------------------
% Form full covariance matrix.
%
  [CCx, SSx, CSx] = CVgen(Qc, Qs, D);
  CVx = [CCx, CSx'; CSx, SSx];
%
% -------------------------------------------------------------------------
% End.
%
% Copyright NPL. No warranty or guarantee applies to this software, and 
% therefore any users should satisfy themselves that it meets their 
% requirements.
% -------------------------------------------------------------------------