function RESULT = FormSubtractFromCompactCV_eig
% -------------------------------------------------------------------------
% FormSubtractFromCompactCV_eig.m
%
% Author         David Humphreys and Peter Harris, NPL
% Created        07-02-2013
% Last amended   07-02-2013
% Released       08-02-2013
% Last amended   15-07-2013   Incorporated path names.
%                02-05-2014   Added input/output parameters.
% Released       30-06-2014
% -------------------------------------------------------------------------
% Form difference of waveform transforms and associated covariance matrix
% in compact form.
%
% See: Guidance for the use of compact covariance uncertainty software,
%      David Humphreys and Peter Harris, NPL REPORT TQE 10, 2014
% -------------------------------------------------------------------------
% Output:
%    RESULT                   Array storing compact representation of
%                             covariance matrix for difference of waveform
%                             transforms.
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% For the first waveform, select a file containing an array RESULT, 
% and load array.
%
  [fname1, pname1] = uigetfile('*.mat', 'Select a RESULT file');
  load([pname1, fname1])
  [~, name1] = fileparts(fname1);
%
% Extract information about compressed covariance matrix from array RESULT.
%
  [n1, DC1, neix1, f01, Rzref1, Izref1, D1, Qc1, Qs1] = ...
     LoadCompactCV_eig(RESULT); %#ok<NODEF>
%
% -------------------------------------------------------------------------
% For the second waveform, select a file containing an array RESULT, 
% and load array.
%
  [fname2, pname2] = uigetfile('*.mat', 'Select a RESULT file');
  load([pname2, fname2])
  [~, name2] = fileparts(fname2);
%
% Extract information about compressed covariance matrix from array RESULT.
%
  [n2, DC2, neix2, f02, Rzref2, Izref2, D2, Qc2, Qs2] = ...
     LoadCompactCV_eig(RESULT);
%
% -------------------------------------------------------------------------
% Check compatability of waveforms.
%
  if (n1 ~= n2) || (f01 ~= f02)
     error('Waveform transforms incompatible for SUBTRACT.')
  end
%
% -------------------------------------------------------------------------
% Form difference of waveform transforms and the associated covariance 
% matrix in compact form.
%
  n     = n1;
  DC    = DC1 - DC2;
  neix  = neix1 + neix2;
  f0    = f01;
  Rzref = Rzref1 - Rzref2;
  Izref = Izref1 - Izref2;
  Qc    = [Qc1, Qc2];
  Qs    = [Qs1, Qs2];
  D     = D1 + D2;
%
% -------------------------------------------------------------------------
% Build array RESULT to store results in a single data structure.
%
  Param  = [n; DC; neix; f0];
  nparam = length(Param);
  Q      = [Qc; Qs];
  RESULT = [nparam; Param; Rzref; Izref; D(:,1); D(:,3); D(:,2); Q(:)];
  name   = [name1, ' SUB ', name2, '.mat'];
%
% Save to MAT file.
%
  [fname, pname] = uiputfile({'*.mat'}, 'Select a RESULT file', name);
  save([pname, fname], 'RESULT')
%
% -------------------------------------------------------------------------
% End.
%
% Copyright NPL. No warranty or guarantee applies to this software, and 
% therefore any users should satisfy themselves that it meets their 
% requirements.
% -------------------------------------------------------------------------