% -------------------------------------------------------------------------
% TestScript.m
%
% Author         David Humphreys and Peter Harris, NPL
% Created        04-02-2013
% Last amended   06-02-2013
% Released       08-02-2013
% Last amended   02-05-2014
% Released       30-06-2014
% -------------------------------------------------------------------------
% See: Guidance for the use of compact covariance uncertainty software,
%      David Humphreys and Peter Harris, NPL REPORT TQE 10, 2014
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Create representation of the average frequency-domain waveform 
% and its associated covariance matrix in compact form.
%
  disp('Create compact representation ...')
  RESULT1 = CreateCompactCV_eig;
%
% Un-pack the compact representation to give the DC component, sampling 
% frequency, and the real and imaginary components of the average
% frequency-domain waveform.
%
  disp('Unpack compact representation ...')
  [DC1, f1, Rz1, Iz1] = FormCovarianceMatrixFromCompactCV_eig(RESULT1);
%
% Form the frequency response with associated standard uncertainties (LPU).
%
  disp('Form frequency response (LPU) ...')
  FormFreqRespFromCompactCV_eig(RESULT1);
%
% Form the frequency response with associated standard uncertainties (MCM).
%
  disp('Form frequency response (MCM) ...')
  FormFreqRespFromCompactCV_eig_MC(RESULT1);
%
% Form an estimate of the time-domain waveform with associated standard 
% uncertainties using the default time vector.
%
  disp('Form time series (default) ...')
  FormTimeSeriesFromCompactCV_eig(0, 0, RESULT1);
%
% Form an estimate of the time-domain waveform with associated standard 
% uncertainties using a phase-shifted time vector.
%
  disp('Form time series (user) ...')
  FormTimeSeriesFromCompactCV_eig(0, length(Rz1), RESULT1);
%
% Create representation of the second average frequency-domain waveform 
% and its associated covariance matrix in compact form.
%
  disp('Create compact representation ...')
  CreateCompactCV_eig;
%
% Form the product of the two average frequency-domain waveforms.
%
  disp('Form product ...')
  FormMultiplyFromCompactCV_eig;
%
% Form the quotient of the two average frequency-domain waveforms.
%
  disp('Form quotient ...')
  FormDivideFromCompactCV_eig;
%
% Form the sum of the two average frequency-domain waveforms.
%
  disp('Form sum ...')
  FormAddFromCompactCV_eig;
%
% Form the difference of the two average frequency-domain waveforms.
%
  disp('Form difference ...')
  FormSubtractFromCompactCV_eig;
%
% Form compact representation of covariance matrix for user-supplied
% frequency-domain waveform (a constant), and un-pack it.
%
  disp('Form covariance matrix for constant frequency-domain waveform ...')
  RESULT2          = FormConstantCompactCV_eig(0, f1, 1, 1, length(Rz1));
  [dc, Rz, Iz, CV] = FormCovarianceMatrixFromCompactCV_eig(RESULT2);
%
% -------------------------------------------------------------------------
% End.
%
% Copyright NPL. No warranty or guarantee applies to this software, and 
% therefore any users should satisfy themselves that it meets their 
% requirements.
% -------------------------------------------------------------------------