function alignment_compact(pname, n, m)
% -------------------------------------------------------------------------
% alignment_compact.m
%
% Author         David Humphreys and Peter Harris, NPL
% Created        23-07-2013   From alignment_compact.m to avoid forming 
%                             full covariance matrix.
% Last amended   26-03-2014   Added input/output parameters.
% Released       30-06-2014
% -------------------------------------------------------------------------
% Alignment of repeated harmonic results without storing all the harmonic 
% results.
%
% See: Guidance for the use of compact covariance uncertainty software,
%      David Humphreys and Peter Harris, NPL REPORT TQE 10, 2014
% -------------------------------------------------------------------------
% Input:
%    pname      string        Pathname to folder containing harmonic
%                             results.
%    n           1 x 1        Number of harmonics (excluding DC).
%    m           1 x 1        Number of waveforms.
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Calculate average of harmonic results.
%
  for j = 1:m
     load([pname, 'tempdata\', int2str(j)]);
     z = z(:,1) + 1i*z(:,2);
     if j == 1
        zref = z;
     else
        zref = zref + (z - zref)/j;
     end
  end  
%
% Calculate average delay correction for each waveform, apply correction,
% store results, and update the average.
%
  dzr = zref(2:n).*conj(zref(1:n-1));
  for j = 1:m
     load([pname, 'tempdata\', int2str(j)]);
     z   = z(:,1) + 1i*z(:,2);
     dz1 = z(2:n).*conj(z(1:n-1));
     dzn = conj(dz1).*dzr;
     dz  = sum(dzn)/abs(sum(dzn));
     z   = z.*(dz.^((1:n)'));
     if j == 1
        zref = z;
     else
        zref = zref + (z - zref)/j;
     end
     z = [real(z), imag(z)];
     save([pname, 'tempdata\', int2str(j)], 'z');
  end
%
% Calculate the delay for the average of the corrected harmonic results.
%
  dzr = conj(zref(2:n)).*zref(1:n-1);
  dz  = sum(dzr)/abs(sum(dzr));
%
% Align the corrected waveforms so that the mean has zero delay.
%
  for j = 1:m
     load([pname, 'tempdata\', int2str(j)]);
     z = z(:,1) + 1i*z(:,2);
     z = z.*(dz.^((1:n)'));
     z = [real(z), imag(z)];
     save([pname, 'tempdata\', int2str(j)], 'z');
  end
%
% -------------------------------------------------------------------------
% End.
%
% Copyright NPL. No warranty or guarantee applies to this software, and 
% therefore any users should satisfy themselves that it meets their 
% requirements.
% -------------------------------------------------------------------------