function [CC, SS, CS] = fullcovariance(z, zref)
% -------------------------------------------------------------------------
% fullcovariance.m
%
% Author         David Humphreys and Peter Harris, NPL
% Created        07-06-2012
% Last amended   18-07-2012   Division by (m - 1) rather than m.
% Released       08-02-2013
% Last amended   26-03-2014   Division by m to give uncertainty matrix.
% Released       30-06-2014
% -------------------------------------------------------------------------
% Create full covariance matrix from repeated harmonic results.
%
% See: Guidance for the use of compact covariance uncertainty software,
%      David Humphreys and Peter Harris, NPL REPORT TQE 10, 2014
% -------------------------------------------------------------------------
% Input:
%    z           n x m        Complex array storing m repeated measurements
%                             of n harmonic results.
%    zref        n x 1        Complex array storing averages of n harmonic
%                             results.
%
% Output:
%    CC,
%    SS,
%    CS          n x n        Submatrices defining full covariance matrix:
%                                V = [CC, CS'; CS, SS]
% -------------------------------------------------------------------------

% -------------------------------------------------------------------------
% Number m of waveforms.
%
  m = size(z,2);
%
% Calculate full Re/Re, Im/Im and Im/Re covariance matrices.
%
  eRc = real(z - zref*ones(1,m));
  eRs = imag(z - zref*ones(1,m));
  CC  = eRc*eRc'/(m*(m-1));
  SS  = eRs*eRs'/(m*(m-1));
  CS  = eRs*eRc'/(m*(m-1));
%
% -------------------------------------------------------------------------
% End.
%
% Copyright NPL. No warranty or guarantee applies to this software, and 
% therefore any users should satisfy themselves that it meets their 
% requirements.
% -------------------------------------------------------------------------